<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\Models\User;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'nom' => ['required', 'string', 'max:255'],
            'prenomsP' => ['required', 'string', 'max:255'],
            'dateNaisP' => ['required', 'string', 'max:255'],
            'professionP' => ['required', 'string', 'max:255'],
            'quartierP' => ['required', 'string', 'max:255'],
            'villeP' => ['required', 'string', 'max:255'],
            'genreP' => ['required', 'string', 'max:255'],
            'pays' => ['required', 'string', 'max:255'],
            'contact' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

        /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validatorM(array $data)
    {
        return Validator::make($data, [
            'nom' => ['required', 'string', 'max:255'],
            'numEM' => ['required', 'string', 'max:255'],
            'numIdentifM' => ['required', 'string', 'max:255'],
            'dateCreationM' => ['required', 'string', 'max:255'],
            'adresseM' => ['required', 'string', 'max:255'],
            'detailCompteM' => ['required', 'string', 'max:255'],
            'nomCompteM' => ['required', 'string', 'max:255'],
            'numCompteM' => ['required', 'string', 'max:255'],
            'pays' => ['required', 'string', 'max:255'],
            'contact' => ['required', 'string', 'max:255', 'min:8'],
            'nomBanqueM' => ['required', 'string', 'max:255'],
            'codeGuichetM' => ['required', 'string', 'max:255'],
            'ibanM' => ['required', 'string', 'max:255'],
            'bicSM' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }


    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
    protected function create(array $data)
    {
        return User::create([
            'nom' => $data['nom'],
            'prenomsP' => $data['prenomsP'],
            'dateNaisP' => $data['dateNaisP'],
            'professionP' => $data['professionP'],
            'quartierP' => $data['quartierP'],
            'villeP' => $data['villeP'],
            'genreP' => $data['genreP'],
            'pays' => $data['pays'],
            'contact' => $data['contact'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
            'status' => 'P'
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
    protected function createM(array $data)
    {
        return User::create([
            'nom' => $data['nom'],
            'numEM' => $data['numEM'],
            'numIdentifM' => $data['numIdentifM'],
            'dateCreationM' => $data['dateCreationM'],
            'adresseM' => $data['adresseM'],
            'detailCompteM' => $data['detailCompteM'],
            'nomCompteM' => $data['nomCompteM'],
            'numCompteM' => $data['numCompteM'],
            'nomBanqueM' => $data['nomBanqueM'],
            'codeGuichetM' => $data['codeGuichetM'],
            'ibanM' => $data['ibanM'],
            'bicSM' => $data['bicSM'],
            'pays' => $data['pays'],
            'contact' => $data['contact'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
            'status' => 'M'
        ]);
    }
}
